pub enum HmacAlgorithm {
HmacSha3_256,
HmacSha3_512,
}Expand description
High-level HMAC selector
Variants
Implementations
Sourceimpl HmacAlgorithm
impl HmacAlgorithm
Sourcepub fn mac(&self, key: &[u8], data: &[u8]) -> PqcResult<Vec<u8>>
pub fn mac(&self, key: &[u8], data: &[u8]) -> PqcResult<Vec<u8>>
Compute HMAC of data
Errors
Returns an error if the key has invalid length or HMAC computation fails
Sourcepub fn verify(&self, key: &[u8], data: &[u8], tag: &[u8]) -> PqcResult<()>
pub fn verify(&self, key: &[u8], data: &[u8], tag: &[u8]) -> PqcResult<()>
Verify HMAC tag (constant-time)
Errors
Returns an error if verification fails or the tag is invalid
Sourcepub fn output_size(&self) -> usize
pub fn output_size(&self) -> usize
Get the output size in bytes